<?php
namespace FiloBlu\ScratchAndWin\Controller\Adminhtml\ScratchAndWinDetails;

use Magento\Backend\App\Action;

class Edit extends \Magento\Backend\App\Action
{
    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry = null;

    /**
     * @var \Magento\Framework\View\Result\PageFactory
     */
    protected $resultPageFactory;

    protected $scratchAndWinDetails;

    protected $scratchAndWinDetailsTranslations;

    /**
     * @param Action\Context $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param \Magento\Framework\Registry $registry
     */
    public function __construct(
        Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Registry $registry,
        \FiloBlu\ScratchAndWin\Model\ScratchAndWinDetailsFactory $scratchAndWinDetails,
        \FiloBlu\ScratchAndWin\Model\ScratchAndWinDetailsTranslationsFactory $scratchAndWinDetailsTranslations
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->_coreRegistry = $registry;
        $this->scratchAndWinDetails = $scratchAndWinDetails;
        $this->scratchAndWinDetailsTranslations = $scratchAndWinDetailsTranslations;
        parent::__construct($context);
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('FiloBlu_ScratchAndWin::config');
    }

    /**
     * Init actions
     *
     * @return \Magento\Backend\Model\View\Result\Page
     */
    protected function _initAction()
    {
        // load layout, set active menu and breadcrumbs
        /** @var \Magento\Backend\Model\View\Result\Page $resultPage */
        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('FiloBlu_ScratchAndWin::general_listdetails')
            ->addBreadcrumb(__('ScratchAndWin Details'), __('ScratchAndWin Details'))
            ->addBreadcrumb(__('Manage ScratchAndWin Details'), __('Manage ScratchAndWin Details'));
        return $resultPage;
    }

    public function execute()
    {
        $id = $this->getRequest()->getParam('id');

        $storeId = $this->getRequest()->getParam('store',0);

        $model = $this->scratchAndWinDetails->create();

        $modelTranslations = $this->scratchAndWinDetailsTranslations->create();

        if ($id) {
            $modelTranslations->loadByParentAndStoreId($id,$storeId);

            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager->addError(__('This scratchandwin details no longer exists.'));
                /** \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
                $resultRedirect = $this->resultRedirectFactory->create();

                return $resultRedirect->setPath('*/*/');
            }
        }

        $this->_coreRegistry->register('filoblu_scratchandwindetails', $model);
        $this->_coreRegistry->register('filoblu_scratchandwindetails_translations', $modelTranslations);

        /** @var \Magento\Backend\Model\View\Result\Page $resultPage */
        $resultPage = $this->_initAction();
        $resultPage->addBreadcrumb(
            $id ? __('Edit ScratchAndWin Details') : __('New ScratchAndWin Details'),
            $id ? __('Edit ScratchAndWin Details') : __('New ScratchAndWin Details')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('ScratchAndWin details Page'));
        $resultPage->getConfig()->getTitle()
            ->prepend($model->getId() ? $model->getPromocode() : __('New ScratchAndWin Details'));

        return $resultPage;
    }
}